@@ -1,6 +1,6 @@
 package Data::Riak::HTTP::Request;
 {
-  $Data::Riak::HTTP::Request::VERSION = '1.1';
+  $Data::Riak::HTTP::Request::VERSION = '1.2';
 }
 
 use strict;
@@ -10,10 +10,12 @@ use Moose;
 
 use HTTP::Headers::ActionPack::LinkList;
 
+with 'Data::Riak::Transport::Request';
+
 has method => (
     is => 'ro',
     isa => 'Str',
-    default => 'GET'
+    required => 1,
 );
 
 has uri => (
@@ -60,12 +62,18 @@ has accept => (
     default => '*/*'
 );
 
+has headers => (
+    is      => 'ro',
+    isa     => 'HashRef',
+    default => sub { +{} },
+);
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
 1;
 
-
+__END__
 
 =pod
 
@@ -75,20 +83,27 @@ Data::Riak::HTTP::Request
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Andrew Nelson <anelson at cpan.org>
 
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
