@@ -1,6 +1,6 @@
 package Data::Riak::Link;
 {
-  $Data::Riak::Link::VERSION = '1.1';
+  $Data::Riak::Link::VERSION = '1.2';
 }
 
 use strict;
@@ -11,6 +11,8 @@ use Moose;
 use URL::Encode qw/url_encode url_decode/;
 use HTTP::Headers::ActionPack::LinkHeader;
 
+use namespace::autoclean;
+
 has bucket => (
     is => 'ro',
     isa => 'Str',
@@ -85,11 +87,10 @@ sub as_link_header {
 
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 
 1;
 
-
+__END__
 
 =pod
 
@@ -99,20 +100,27 @@ Data::Riak::Link
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Andrew Nelson <anelson at cpan.org>
 
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
