@@ -1,21 +1,23 @@
 package Data::Riak::MapReduce::Phase;
 {
-  $Data::Riak::MapReduce::Phase::VERSION = '1.1';
+  $Data::Riak::MapReduce::Phase::VERSION = '1.2';
 }
 
 use Moose::Role;
 
 
 has keep => (
-    is => 'rw',
-    isa => 'Bool',
+    is        => 'ro',
+    isa       => 'Bool',
     predicate => 'has_keep',
 );
 
 requires 'pack';
 
 no Moose::Role; 1;
+
 __END__
+
 =pod
 
 =head1 NAME
@@ -24,7 +26,7 @@ Data::Riak::MapReduce::Phase
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 DESCRIPTION
 
@@ -44,16 +46,25 @@ result of the map/reduce.
 
 The C<pack> method is required to be implemented by consumers of this role.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Andrew Nelson <anelson at cpan.org>
 
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
