@@ -1,10 +1,11 @@
 package Data::Riak::MapReduce::Phase::Link;
 {
-  $Data::Riak::MapReduce::Phase::Link::VERSION = '1.1';
+  $Data::Riak::MapReduce::Phase::Link::VERSION = '1.2';
 }
 use Moose;
 
 use JSON::XS ();
+use namespace::autoclean;
 
 # ABSTRACT: Link phase of a MapReduce
 
@@ -12,21 +13,21 @@ with ('Data::Riak::MapReduce::Phase');
 
 
 has bucket => (
-    is => 'rw',
-    isa => 'Str',
+    is        => 'ro',
+    isa       => 'Str',
     predicate => 'has_bucket'
 );
 
 has phase => (
-    is => 'ro',
-    isa => 'Str',
+    is      => 'ro',
+    isa     => 'Str',
     default => 'link'
 );
 
 
 has tag => (
-    is => 'rw',
-    isa => 'Str',
+    is        => 'ro',
+    isa       => 'Str',
     predicate => 'has_tag'
 );
 
@@ -44,7 +45,9 @@ sub pack {
 }
 
 1;
+
 __END__
+
 =pod
 
 =head1 NAME
@@ -53,7 +56,7 @@ Data::Riak::MapReduce::Phase::Link - Link phase of a MapReduce
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -83,16 +86,25 @@ The name of the tag of links that should be followed
 
 Serialize this link phase.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Andrew Nelson <anelson at cpan.org>
 
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
