@@ -1,26 +1,20 @@
 package Data::Riak::Role::HasRiak;
 {
-  $Data::Riak::Role::HasRiak::VERSION = '1.1';
+  $Data::Riak::Role::HasRiak::VERSION = '1.2';
 }
 
-use strict;
-use warnings;
-
 use Moose::Role;
-
-use Data::Riak;
+use namespace::autoclean;
 
 has riak => (
-    is => 'ro',
-    isa => 'Data::Riak',
+    is       => 'ro',
+    isa      => 'Data::Riak',
     required => 1
 );
 
-no Moose::Role;
-
 1;
 
-
+__END__
 
 =pod
 
@@ -30,20 +24,27 @@ Data::Riak::Role::HasRiak
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Andrew Nelson <anelson at cpan.org>
 
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
