@@ -1,6 +1,6 @@
 package Data::Riak::Types;
 {
-  $Data::Riak::Types::VERSION = '1.1';
+  $Data::Riak::Types::VERSION = '1.2';
 }
 
 use strict;
@@ -12,7 +12,7 @@ use Moose::Util::TypeConstraints;
 
 no Moose::Util::TypeConstraints; 1;
 
-
+__END__
 
 =pod
 
@@ -22,20 +22,27 @@ Data::Riak::Types
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Andrew Nelson <anelson at cpan.org>
 
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive.
+This software is copyright (c) 2013 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
